@@ -12,7 +12,7 @@
 
 name = "DFRobot_siot"
 
-__all__ = ['init', 'connect', 'publish', 'subscribe', '_on_connect', '_on_disconnect', 'set_callback', 'getsubscribe', 'stop', 'publloopish', '_loop']
+__all__ = ['init', 'connect', 'publish','publish_save', 'subscribe', '_on_connect', '_on_disconnect', 'set_callback', 'getsubscribe', 'stop', 'publloopish', '_loop']
 
 import threading
 import paho.mqtt.client as mqtt
@@ -57,8 +57,8 @@ def connect():
 def publish(topic, data):
     client.publish(str(topic), str(data),qos=0)
 
-def publish_save(topic, data):
-    client.publish(str(topic), str(data),qos=1)
+def publish_save(topic, data,qos=1):
+    client.publish(str(topic), str(data),qos=qos)
    
 def subscribe(topic, cb):
     client.on_message  = cb
